function[M,P,Q,pointsWAa,pointsWAb]=skillscaleauto(Y,TNAS,TNA1S,F,rf,n,T,indicsb)
%This routine computes the distributions of skill and scalability

%inputs:
%Y is the n_chi x T vector of fund gross excess returns (after the
%selection rule in Eq. (8) (i.e., we have dimension n_chi instead of n).
%TNAS is is the n_chi x T vector of fund lagged size (each column of TNAS is standardized to have a standard deviation of one). 
%TNA1S is is the n_chi x T vector of fund size innovation based on the Amihud-Hurvich procedure described in the appendix (each column of TNA1S is standardized to have a standard deviation of one). 
%F is the T x (K_f) vector of factor excess returns (including a constant).
%rf is the T x 1 vector of riskfree rate.
%n is the total number of funds (before applying the selection rule in Eq. (8)).
%T is the total number of observations.
%indicsb equals 1 if we do not adjust for the small-sample bias (i.e., we
%compute ai and bi without TNA1S), or 2 if we if we adjust for the small-sample bias (i.e., we
%compute ai and bi with TNA1S).

%outputs: 
%M is the 4 x 2 matrix of bias-adjusted (moments, standard deviation, skewness,
%kurtosis) for the skill and scale coefficients.
%P is the 2 x 2 matrix of bias-adjusted proportions (negative and
%positive) for the skill and scale coefficients.
%Q is the 2 x 2 matrix of bias-adjusted quantiles (5% and 95%) for the skill and scale coefficients.
%pointsWAa is the nbpoints x 2 matrix, which contains the grid of points m and the bias-adjusted density value for the skill coefficient.
%pointsWAb is the nbpoints x 2 matrix, which contains the grid of points m and the bias-adjusted density value for the scale coefficient.

%computation of the skill and scale coefficients and asymptotic variance
%choice of the lag for the computation of the asymptotic variance
lagnew=3;
[alphatot,Sitot]=skillscale(Y,TNAS,TNA1S,F,rf,lagnew,indicsb);

%analysis of skill
alphaa=alphatot(:,1);
Sia=Sitot(:,1);
%trimming of extreme values 
%choice of the threshold for trimming (based on standardized values)
thres=10;
[alphaat,Siat]=trim(alphaa,Sia,thres);

%computation of the characteristics of the skill distribution
%choice of the number of values for the grid of points for the estimation of the density
nbpoints=2000;
[Ma,Pa,Qa,pointsWAa]=EIVbiasadjust(alphaat,Siat,n,T,nbpoints);

%analysis of scalability
alphab=alphatot(:,2);
Sib=Sitot(:,2);
%trimming of extreme values 
%choice of the threshold for trimming (based on standardized values)
thres=10;
[alphabt,Sibt]=trim(alphab,Sib,thres);

%computation of the characteristics of the skill distribution
%choice of the number of values for the grid of points for the estimation of the density
nbpoints=2000;
[Mb,Pb,Qb,pointsWAb]=EIVbiasadjust(alphabt,Sibt,n,T,nbpoints);
M=[Ma,Mb];
P=[Pa,Pb];
Q=[Qa,Qb];