function[vatot,Sivatot]=va(Y,TNA,TNA1,F,rf,lagnew,indicsb,nbperiod)
%This routine computes the vector of estimated value added (entire period and last subperiod)
%along with their asymptotic variance (Si).

nbfond=size(Y,2);
nbobs0=size(Y,1);
vatot=zeros(nbfond,2);
Sivatot=zeros(nbfond,2);
for i=1:nbfond,
    %We compute the gross returns.
    %We put a minus sign to be consistent with Berk and Green.
    %We undo the standardization to compute the formulas for the uit
    index=find(Y(:,i)~=-999);
    Ii=zeros(nbobs0,1);
    Ii(index,1)=1;
    nbobs=size(index,1);
    resi=zeros(nbobs0,1);
    tau=nbobs0/nbobs;
    Fsel=F(index,:);
    if indicsb==1,
        tsel=TNA(index,i);
        t=TNA(:,i);
        tcsel=[tsel];
        tc=[t];
        Xsel=[Fsel(:,1),-tcsel,Fsel(:,2:end)];
        Xtot=[F(:,1),-tc,F(:,2:end)];   
    else
        tsel=TNA(index,i);
        t=TNA(:,i);
        t1sel=TNA1(index,i);
        t1=TNA1(:,i);
        tcsel=[tsel,t1sel];
        tc=[t,t1];
        Xsel=[Fsel(:,1),-tcsel,Fsel(:,2:end)];
        Xtot=[F(:,1),-tc,F(:,2:end)]; 
    end
    invQx=inv((1/nbobs)*Xsel'*Xsel);
    rfsel=rf(index,1);
    Ysel=Y(index,i)-rfsel;
    [beta,BINT,residus0,RINT,statistique]=regress(Ysel,Xsel);
    a=beta(1,1);
    b=beta(2,1);
    resi(index,1)=residus0;
    
    
    %computation of the value added over the entire period
    m1=mean(tsel);
    m2=mean(tsel.^2);
    vatot(i,1)=(a*m1-b*m2);
   
    %computation of the asymptotic variance
    nbreg=size(Xsel,2);
    snb=1/sqrt(nbobs0);
    E1=zeros(nbreg,1);
    E1(1,1)=1;
    E2=zeros(nbreg,1);
    E2(2,1)=1;
    ui1=Ii.*(m1*E1'*invQx*Xtot')'.*resi+Ii.*(a*(t-ones(nbobs0,1)*m1));
    ui2=Ii.*(m2*E2'*invQx*Xtot')'.*resi+Ii.*(b*(t.^2-ones(nbobs0,1)*m2));
    uil=ui1-ui2;
    cst=(tau*snb)^2;
    [Sit]=calculSit(uil,cst,lagnew);
    Sivatot(i,1)=Sit;
   
    
    %computation of the last subperiod value added
    nb1=round(nbobs/nbperiod);
    indic=(size(index,1)-nb1+1:size(index,1));
    m1=mean(tsel(indic,1));
    m2=mean(tsel(indic,1).^2);
    vatot(i,2)=(a*m1-b*m2);
    
    %computation of the asymptotic variance
    E1=zeros(nbreg,1);
    E1(1,1)=1;
    E2=zeros(nbreg,1);
    E2(2,1)=1;
    uil=Ii.*(m1*E1'*invQx*Xtot')'.*resi-Ii.*(m2*E2'*invQx*Xtot')'.*resi;
    cst=(tau*snb)^2;
    [Sit]=calculSit(uil,cst,lagnew);
    Sivatot(i,2)=Sit;
end