function[M,P,Q,pointsWAa,pointsWAb]=vaauto(Y,TNA,TNA1,F,rf,n,T,indicsb)
%This routine computes the distributions of value added (entire period and last subperiod)

%inputs:
%Y is the n_chi x T vector of fund gross excess returns (after the
%selection rule in Equ. (8) (so we have dimension n_chi instead of n).
%TNA is is the n_chi x T vector of fund lagged size. 
%TNA1 is is the n_chi x T vector of fund size innovation based on the Amihud-Hurvich procedure. 
%F is the T x (K_f+1) vector of factor excess returns (including a constant).
%rf is the T x 1 vector of riskfree rate
%n is the total number of funds (before applying the selection rule in Eq. (8)).
%T is the total number of observations.
%indicsb equals 1 if we do not adjust for the small-sample bias (i.e., we
%compute ai and bi without TNA1), or 2 if we if we adjust for the small-sample bias (i.e., we
%compute ai and bi with TNA1).

%outputs: 
%M is the 4 X 2 matrix of bias-adjusted (moments, standard deviation, skewness,
%kurtosis) for the value added (entire period and last subperiod).
%P is the 2 x 2 matrix of bias-adjusted proportions (negative and
%positive) for the value added (entire period and last subperiod).
%Q is the 2 x 2 matrix of bias-adjusted quantiles (5% and 95%) for the skill and scale coefficients.
%pointsWAa is the nbpoints x 2 matrix, which contains the grid of points m and the bias-adjusted density value for the value added (entire period).
%pointsWAb is the nbpoints x 2 matrix, which contains the grid of points m and the bias-adjusted density value for the value added (last subperiod).



%computation of the value added (entire period and last subperiod) and asymptotic variance
%choice of the lag for the computation of the asymptotic variance
lagnew=3;
%choice of the number of periods for the last subperiod value added
nbperiod=10;
[vatot,Sivatot]=va(Y,TNA,TNA1,F,rf,lagnew,indicsb,nbperiod);

%analysis of value added over the entire period
alphava=vatot(:,1);
Siva=Sivatot(:,1);
%trimming of extreme values 
%choice of the threshold for trimming (based on standardized values)
thres=10;
[alphavat,Sivat]=trim(alphava,Siva,thres);

%computation of the characteristics of the skill distribution
%choice of the number of values for the grid of points for the estimation of the density
nbpoints=2000;
[Ma,Pa,Qa,pointsWAa]=EIVbiasadjust(alphavat,Sivat,n,T,nbpoints);

%analysis of the last subperiod value added
alphavas=vatot(:,2);
Sivas=Sivatot(:,2);
%trimming of extreme values 
%choice of the threshold for trimming (based on standardized values)
thres=10;
[alphavast,Sivast]=trim(alphavas,Sivas,thres);

%computation of the characteristics of the skill distribution
%choice of the number of values for the grid of points for the estimation of the density
nbpoints=2000;
[Mb,Pb,Qb,pointsWAb]=EIVbiasadjust(alphavast,Sivast,n,T,nbpoints);
M=[Ma,Mb];
P=[Pa,Pb];
Q=[Qa,Qb];